# coding: utf-8

"""
    Trackside Software TeamDB API v2.0

    This API enables you to access TeamDB data  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@trackside.fr
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from teamdbapi.api_client import ApiClient


class ParameterApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def parameter_get_current_context_parameter_by_name(self, param_name_or_reference, **kwargs):  # noqa: E501
        """Get the parameter for a given parameter name or reference and the current selected version in the Parameters Editor view.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.parameter_get_current_context_parameter_by_name(param_name_or_reference, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str param_name_or_reference: The parameter name or reference to find. (required)
        :return: Parameter
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.parameter_get_current_context_parameter_by_name_with_http_info(param_name_or_reference, **kwargs)  # noqa: E501
        else:
            (data) = self.parameter_get_current_context_parameter_by_name_with_http_info(param_name_or_reference, **kwargs)  # noqa: E501
            return data

    def parameter_get_current_context_parameter_by_name_with_http_info(self, param_name_or_reference, **kwargs):  # noqa: E501
        """Get the parameter for a given parameter name or reference and the current selected version in the Parameters Editor view.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.parameter_get_current_context_parameter_by_name_with_http_info(param_name_or_reference, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str param_name_or_reference: The parameter name or reference to find. (required)
        :return: Parameter
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['param_name_or_reference']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method parameter_get_current_context_parameter_by_name" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'param_name_or_reference' is set
        if self.api_client.client_side_validation and ('param_name_or_reference' not in params or
                                                       params['param_name_or_reference'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `param_name_or_reference` when calling `parameter_get_current_context_parameter_by_name`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'param_name_or_reference' in params:
            query_params.append(('paramNameOrReference', params['param_name_or_reference']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/currentVersion/parameter', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Parameter',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def parameter_get_parameter_by_name_for_version(self, version_id, param_name_or_reference, **kwargs):  # noqa: E501
        """Get the parameter for a given parameter name or reference and a version unique id  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.parameter_get_parameter_by_name_for_version(version_id, param_name_or_reference, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str version_id: The unique version Id containing the parameter (required)
        :param str param_name_or_reference: The parameter name or reference to find. (required)
        :return: Parameter
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.parameter_get_parameter_by_name_for_version_with_http_info(version_id, param_name_or_reference, **kwargs)  # noqa: E501
        else:
            (data) = self.parameter_get_parameter_by_name_for_version_with_http_info(version_id, param_name_or_reference, **kwargs)  # noqa: E501
            return data

    def parameter_get_parameter_by_name_for_version_with_http_info(self, version_id, param_name_or_reference, **kwargs):  # noqa: E501
        """Get the parameter for a given parameter name or reference and a version unique id  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.parameter_get_parameter_by_name_for_version_with_http_info(version_id, param_name_or_reference, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str version_id: The unique version Id containing the parameter (required)
        :param str param_name_or_reference: The parameter name or reference to find. (required)
        :return: Parameter
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['version_id', 'param_name_or_reference']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method parameter_get_parameter_by_name_for_version" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'version_id' is set
        if self.api_client.client_side_validation and ('version_id' not in params or
                                                       params['version_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `version_id` when calling `parameter_get_parameter_by_name_for_version`")  # noqa: E501
        # verify the required parameter 'param_name_or_reference' is set
        if self.api_client.client_side_validation and ('param_name_or_reference' not in params or
                                                       params['param_name_or_reference'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `param_name_or_reference` when calling `parameter_get_parameter_by_name_for_version`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'version_id' in params:
            path_params['versionId'] = params['version_id']  # noqa: E501

        query_params = []
        if 'param_name_or_reference' in params:
            query_params.append(('paramNameOrReference', params['param_name_or_reference']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/version/{versionId}/parameter', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Parameter',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def parameter_get_parameter(self, param_id, version_id, **kwargs):  # noqa: E501
        """Get a parameter for a given version id.  A parameter can be linked to different versions with the same definition... or not (for ex: new parameter size, format...).  For this reason, you have to specify the version to which you want to get the paramater definition.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.parameter_get_parameter(param_id, version_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str param_id: The unique parameter id to get. (required)
        :param str version_id: The version id to which you want to get the parameter definition (required)
        :return: Parameter
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.parameter_get_parameter_with_http_info(param_id, version_id, **kwargs)  # noqa: E501
        else:
            (data) = self.parameter_get_parameter_with_http_info(param_id, version_id, **kwargs)  # noqa: E501
            return data

    def parameter_get_parameter_with_http_info(self, param_id, version_id, **kwargs):  # noqa: E501
        """Get a parameter for a given version id.  A parameter can be linked to different versions with the same definition... or not (for ex: new parameter size, format...).  For this reason, you have to specify the version to which you want to get the paramater definition.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.parameter_get_parameter_with_http_info(param_id, version_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str param_id: The unique parameter id to get. (required)
        :param str version_id: The version id to which you want to get the parameter definition (required)
        :return: Parameter
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['param_id', 'version_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method parameter_get_parameter" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'param_id' is set
        if self.api_client.client_side_validation and ('param_id' not in params or
                                                       params['param_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `param_id` when calling `parameter_get_parameter`")  # noqa: E501
        # verify the required parameter 'version_id' is set
        if self.api_client.client_side_validation and ('version_id' not in params or
                                                       params['version_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `version_id` when calling `parameter_get_parameter`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'param_id' in params:
            path_params['paramId'] = params['param_id']  # noqa: E501
        if 'version_id' in params:
            path_params['versionId'] = params['version_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/version/{versionId}/parameter/{paramId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Parameter',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def parameter_get_parameters_in_group(self, version_id, group_id, **kwargs):  # noqa: E501
        """Get all parameters contained inside a group, including the parameters inside the child groups  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.parameter_get_parameters_in_group(version_id, group_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str version_id: The unique version id to which the group belongs. (required)
        :param str group_id: The unique group id to which you want the parameters. (required)
        :return: list[Parameter]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.parameter_get_parameters_in_group_with_http_info(version_id, group_id, **kwargs)  # noqa: E501
        else:
            (data) = self.parameter_get_parameters_in_group_with_http_info(version_id, group_id, **kwargs)  # noqa: E501
            return data

    def parameter_get_parameters_in_group_with_http_info(self, version_id, group_id, **kwargs):  # noqa: E501
        """Get all parameters contained inside a group, including the parameters inside the child groups  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.parameter_get_parameters_in_group_with_http_info(version_id, group_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str version_id: The unique version id to which the group belongs. (required)
        :param str group_id: The unique group id to which you want the parameters. (required)
        :return: list[Parameter]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['version_id', 'group_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method parameter_get_parameters_in_group" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'version_id' is set
        if self.api_client.client_side_validation and ('version_id' not in params or
                                                       params['version_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `version_id` when calling `parameter_get_parameters_in_group`")  # noqa: E501
        # verify the required parameter 'group_id' is set
        if self.api_client.client_side_validation and ('group_id' not in params or
                                                       params['group_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `group_id` when calling `parameter_get_parameters_in_group`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'version_id' in params:
            path_params['versionId'] = params['version_id']  # noqa: E501
        if 'group_id' in params:
            path_params['groupId'] = params['group_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/version/{versionId}/group/{groupId}/parameters', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[Parameter]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def parameter_get_parameters(self, version_id, **kwargs):  # noqa: E501
        """Get all parameters for a given version  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.parameter_get_parameters(version_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str version_id: The unique version id to which you want the parameters. (required)
        :return: list[Parameter]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.parameter_get_parameters_with_http_info(version_id, **kwargs)  # noqa: E501
        else:
            (data) = self.parameter_get_parameters_with_http_info(version_id, **kwargs)  # noqa: E501
            return data

    def parameter_get_parameters_with_http_info(self, version_id, **kwargs):  # noqa: E501
        """Get all parameters for a given version  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.parameter_get_parameters_with_http_info(version_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str version_id: The unique version id to which you want the parameters. (required)
        :return: list[Parameter]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['version_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method parameter_get_parameters" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'version_id' is set
        if self.api_client.client_side_validation and ('version_id' not in params or
                                                       params['version_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `version_id` when calling `parameter_get_parameters`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'version_id' in params:
            path_params['versionId'] = params['version_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/version/{versionId}/parameters', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[Parameter]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def parameter_import_parameters(self, version_id, import_options, **kwargs):  # noqa: E501
        """Import parameter files  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.parameter_import_parameters(version_id, import_options, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str version_id: The unique id of the version to which the paramterers will be imported. (required)
        :param ImportParametersArgs import_options: The import options (required)
        :return: ImportParametersResults
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.parameter_import_parameters_with_http_info(version_id, import_options, **kwargs)  # noqa: E501
        else:
            (data) = self.parameter_import_parameters_with_http_info(version_id, import_options, **kwargs)  # noqa: E501
            return data

    def parameter_import_parameters_with_http_info(self, version_id, import_options, **kwargs):  # noqa: E501
        """Import parameter files  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.parameter_import_parameters_with_http_info(version_id, import_options, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str version_id: The unique id of the version to which the paramterers will be imported. (required)
        :param ImportParametersArgs import_options: The import options (required)
        :return: ImportParametersResults
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['version_id', 'import_options']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method parameter_import_parameters" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'version_id' is set
        if self.api_client.client_side_validation and ('version_id' not in params or
                                                       params['version_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `version_id` when calling `parameter_import_parameters`")  # noqa: E501
        # verify the required parameter 'import_options' is set
        if self.api_client.client_side_validation and ('import_options' not in params or
                                                       params['import_options'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `import_options` when calling `parameter_import_parameters`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'version_id' in params:
            path_params['versionId'] = params['version_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'import_options' in params:
            body_params = params['import_options']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json-patch+json', 'application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/version/{versionId}/parameter/import', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ImportParametersResults',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def parameter_move_parameter(self, version_id, group_id, param_ids, **kwargs):  # noqa: E501
        """[Command] Move one or more parameters to a group  # noqa: E501

        Set groupId to 00000000-0000-0000-0000-000000000000 in order to move the parameter on the root.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.parameter_move_parameter(version_id, group_id, param_ids, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str version_id: The version id on which you are working (required)
        :param str group_id: The destination group id where to move the parameters (required)
        :param list[str] param_ids: The list of unique parameter ids to move inside the destination group (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.parameter_move_parameter_with_http_info(version_id, group_id, param_ids, **kwargs)  # noqa: E501
        else:
            (data) = self.parameter_move_parameter_with_http_info(version_id, group_id, param_ids, **kwargs)  # noqa: E501
            return data

    def parameter_move_parameter_with_http_info(self, version_id, group_id, param_ids, **kwargs):  # noqa: E501
        """[Command] Move one or more parameters to a group  # noqa: E501

        Set groupId to 00000000-0000-0000-0000-000000000000 in order to move the parameter on the root.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.parameter_move_parameter_with_http_info(version_id, group_id, param_ids, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str version_id: The version id on which you are working (required)
        :param str group_id: The destination group id where to move the parameters (required)
        :param list[str] param_ids: The list of unique parameter ids to move inside the destination group (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['version_id', 'group_id', 'param_ids']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method parameter_move_parameter" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'version_id' is set
        if self.api_client.client_side_validation and ('version_id' not in params or
                                                       params['version_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `version_id` when calling `parameter_move_parameter`")  # noqa: E501
        # verify the required parameter 'group_id' is set
        if self.api_client.client_side_validation and ('group_id' not in params or
                                                       params['group_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `group_id` when calling `parameter_move_parameter`")  # noqa: E501
        # verify the required parameter 'param_ids' is set
        if self.api_client.client_side_validation and ('param_ids' not in params or
                                                       params['param_ids'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `param_ids` when calling `parameter_move_parameter`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'version_id' in params:
            path_params['versionId'] = params['version_id']  # noqa: E501
        if 'group_id' in params:
            path_params['groupId'] = params['group_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'param_ids' in params:
            body_params = params['param_ids']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json-patch+json', 'application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/version/{versionId}/group/{groupId}/moveparameter', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def parameter_move_parameter(self, version_id, group_id, reference_assembly_id, param_ids, **kwargs):  # noqa: E501
        """Move a parameter inside a group and update the involved group revisions based on the reference assembly given in argument  # noqa: E501

        Set groupId to 00000000-0000-0000-0000-000000000000 in order to move the parameter on the root.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.parameter_move_parameter(version_id, group_id, reference_assembly_id, param_ids, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str version_id: The version id on which you are working (required)
        :param str group_id: The destination group id where to move the parameters (required)
        :param str reference_assembly_id: The assembly id used as a reference in order to update the group revision potentially involved in the process. (required)
        :param list[str] param_ids: The list of unique parameter ids to move inside the destination group (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.parameter_move_parameter_with_http_info(version_id, group_id, reference_assembly_id, param_ids, **kwargs)  # noqa: E501
        else:
            (data) = self.parameter_move_parameter_with_http_info(version_id, group_id, reference_assembly_id, param_ids, **kwargs)  # noqa: E501
            return data

    def parameter_move_parameter_with_http_info(self, version_id, group_id, reference_assembly_id, param_ids, **kwargs):  # noqa: E501
        """Move a parameter inside a group and update the involved group revisions based on the reference assembly given in argument  # noqa: E501

        Set groupId to 00000000-0000-0000-0000-000000000000 in order to move the parameter on the root.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.parameter_move_parameter_with_http_info(version_id, group_id, reference_assembly_id, param_ids, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str version_id: The version id on which you are working (required)
        :param str group_id: The destination group id where to move the parameters (required)
        :param str reference_assembly_id: The assembly id used as a reference in order to update the group revision potentially involved in the process. (required)
        :param list[str] param_ids: The list of unique parameter ids to move inside the destination group (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['version_id', 'group_id', 'reference_assembly_id', 'param_ids']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method parameter_move_parameter" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'version_id' is set
        if self.api_client.client_side_validation and ('version_id' not in params or
                                                       params['version_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `version_id` when calling `parameter_move_parameter`")  # noqa: E501
        # verify the required parameter 'group_id' is set
        if self.api_client.client_side_validation and ('group_id' not in params or
                                                       params['group_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `group_id` when calling `parameter_move_parameter`")  # noqa: E501
        # verify the required parameter 'reference_assembly_id' is set
        if self.api_client.client_side_validation and ('reference_assembly_id' not in params or
                                                       params['reference_assembly_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `reference_assembly_id` when calling `parameter_move_parameter`")  # noqa: E501
        # verify the required parameter 'param_ids' is set
        if self.api_client.client_side_validation and ('param_ids' not in params or
                                                       params['param_ids'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `param_ids` when calling `parameter_move_parameter`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'version_id' in params:
            path_params['versionId'] = params['version_id']  # noqa: E501
        if 'group_id' in params:
            path_params['groupId'] = params['group_id']  # noqa: E501

        query_params = []
        if 'reference_assembly_id' in params:
            query_params.append(('referenceAssemblyId', params['reference_assembly_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'param_ids' in params:
            body_params = params['param_ids']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json-patch+json', 'application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/version/{versionId}/group/{groupId}/moveparameterupdaterevision', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def parameter_reset_responsible(self, version_id, param_ids, **kwargs):  # noqa: E501
        """Reset the responsible for a given version and a list of parameters  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.parameter_reset_responsible(version_id, param_ids, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str version_id: The version unique id to which the responsible will be reseted (required)
        :param list[str] param_ids: The parameters list to which the responsible will be reseted (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.parameter_reset_responsible_with_http_info(version_id, param_ids, **kwargs)  # noqa: E501
        else:
            (data) = self.parameter_reset_responsible_with_http_info(version_id, param_ids, **kwargs)  # noqa: E501
            return data

    def parameter_reset_responsible_with_http_info(self, version_id, param_ids, **kwargs):  # noqa: E501
        """Reset the responsible for a given version and a list of parameters  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.parameter_reset_responsible_with_http_info(version_id, param_ids, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str version_id: The version unique id to which the responsible will be reseted (required)
        :param list[str] param_ids: The parameters list to which the responsible will be reseted (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['version_id', 'param_ids']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method parameter_reset_responsible" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'version_id' is set
        if self.api_client.client_side_validation and ('version_id' not in params or
                                                       params['version_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `version_id` when calling `parameter_reset_responsible`")  # noqa: E501
        # verify the required parameter 'param_ids' is set
        if self.api_client.client_side_validation and ('param_ids' not in params or
                                                       params['param_ids'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `param_ids` when calling `parameter_reset_responsible`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'version_id' in params:
            path_params['versionId'] = params['version_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'param_ids' in params:
            body_params = params['param_ids']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json-patch+json', 'application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/version/{versionId}/parameter/resetresponsible', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def parameter_select_parameter_by_id(self, parameter_id, **kwargs):  # noqa: E501
        """[Command] Select the given parameter in the Edit Car Parameters view  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.parameter_select_parameter_by_id(parameter_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str parameter_id: The parameter unique Id to select in the Edit Car Parameters view (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.parameter_select_parameter_by_id_with_http_info(parameter_id, **kwargs)  # noqa: E501
        else:
            (data) = self.parameter_select_parameter_by_id_with_http_info(parameter_id, **kwargs)  # noqa: E501
            return data

    def parameter_select_parameter_by_id_with_http_info(self, parameter_id, **kwargs):  # noqa: E501
        """[Command] Select the given parameter in the Edit Car Parameters view  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.parameter_select_parameter_by_id_with_http_info(parameter_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str parameter_id: The parameter unique Id to select in the Edit Car Parameters view (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['parameter_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method parameter_select_parameter_by_id" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'parameter_id' is set
        if self.api_client.client_side_validation and ('parameter_id' not in params or
                                                       params['parameter_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `parameter_id` when calling `parameter_select_parameter_by_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'parameter_id' in params:
            path_params['parameterId'] = params['parameter_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/parameter/{parameterId}/select', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def parameter_set_responsible(self, version_id, responsible, param_ids, **kwargs):  # noqa: E501
        """[Command] Set the responsible for a given version and a list of parameters  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.parameter_set_responsible(version_id, responsible, param_ids, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str version_id: The version unique id to which the responsible will be affected (required)
        :param str responsible: The responsible name. Must be a Teamdb User name. (required)
        :param list[str] param_ids: The parameters list to which the responsible will be in charge (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.parameter_set_responsible_with_http_info(version_id, responsible, param_ids, **kwargs)  # noqa: E501
        else:
            (data) = self.parameter_set_responsible_with_http_info(version_id, responsible, param_ids, **kwargs)  # noqa: E501
            return data

    def parameter_set_responsible_with_http_info(self, version_id, responsible, param_ids, **kwargs):  # noqa: E501
        """[Command] Set the responsible for a given version and a list of parameters  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.parameter_set_responsible_with_http_info(version_id, responsible, param_ids, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str version_id: The version unique id to which the responsible will be affected (required)
        :param str responsible: The responsible name. Must be a Teamdb User name. (required)
        :param list[str] param_ids: The parameters list to which the responsible will be in charge (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['version_id', 'responsible', 'param_ids']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method parameter_set_responsible" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'version_id' is set
        if self.api_client.client_side_validation and ('version_id' not in params or
                                                       params['version_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `version_id` when calling `parameter_set_responsible`")  # noqa: E501
        # verify the required parameter 'responsible' is set
        if self.api_client.client_side_validation and ('responsible' not in params or
                                                       params['responsible'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `responsible` when calling `parameter_set_responsible`")  # noqa: E501
        # verify the required parameter 'param_ids' is set
        if self.api_client.client_side_validation and ('param_ids' not in params or
                                                       params['param_ids'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `param_ids` when calling `parameter_set_responsible`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'version_id' in params:
            path_params['versionId'] = params['version_id']  # noqa: E501

        query_params = []
        if 'responsible' in params:
            query_params.append(('responsible', params['responsible']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'param_ids' in params:
            body_params = params['param_ids']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json-patch+json', 'application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/version/{versionId}/parameter/setresponsible', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Trackside Software TeamDB API v2.0

    This API enables you to access TeamDB data  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@trackside.fr
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from teamdbapi.api_client import ApiClient


class TargetApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def target_create_target(self, target, **kwargs):  # noqa: E501
        """Create a target  # noqa: E501

        Set the Target.Id to Guid.Empty (00000000-0000-0000-0000-000000000000) if you want to create a new target. The id will be generated by the server.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.target_create_target(target, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param Target target: The target to create. (required)
        :return: Target
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.target_create_target_with_http_info(target, **kwargs)  # noqa: E501
        else:
            (data) = self.target_create_target_with_http_info(target, **kwargs)  # noqa: E501
            return data

    def target_create_target_with_http_info(self, target, **kwargs):  # noqa: E501
        """Create a target  # noqa: E501

        Set the Target.Id to Guid.Empty (00000000-0000-0000-0000-000000000000) if you want to create a new target. The id will be generated by the server.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.target_create_target_with_http_info(target, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param Target target: The target to create. (required)
        :return: Target
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['target']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method target_create_target" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'target' is set
        if self.api_client.client_side_validation and ('target' not in params or
                                                       params['target'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `target` when calling `target_create_target`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'target' in params:
            body_params = params['target']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json-patch+json', 'application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/target', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Target',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def target_get_target(self, id, **kwargs):  # noqa: E501
        """Get a target corresponding to a unique id  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.target_get_target(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: The unique target id that corresponds to the searched target (required)
        :return: Target
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.target_get_target_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.target_get_target_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def target_get_target_with_http_info(self, id, **kwargs):  # noqa: E501
        """Get a target corresponding to a unique id  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.target_get_target_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: The unique target id that corresponds to the searched target (required)
        :return: Target
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method target_get_target" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `target_get_target`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/target/{id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Target',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def target_get_targets(self, **kwargs):  # noqa: E501
        """Get the list of all targets depending on your rights.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.target_get_targets(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: list[Target]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.target_get_targets_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.target_get_targets_with_http_info(**kwargs)  # noqa: E501
            return data

    def target_get_targets_with_http_info(self, **kwargs):  # noqa: E501
        """Get the list of all targets depending on your rights.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.target_get_targets_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: list[Target]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method target_get_targets" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/targets', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[Target]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def target_update_target(self, target_id, updated_target, **kwargs):  # noqa: E501
        """Update a target  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.target_update_target(target_id, updated_target, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str target_id: The target id corresponding to the target you want to update (required)
        :param Target updated_target: The target to update. (required)
        :return: Target
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.target_update_target_with_http_info(target_id, updated_target, **kwargs)  # noqa: E501
        else:
            (data) = self.target_update_target_with_http_info(target_id, updated_target, **kwargs)  # noqa: E501
            return data

    def target_update_target_with_http_info(self, target_id, updated_target, **kwargs):  # noqa: E501
        """Update a target  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.target_update_target_with_http_info(target_id, updated_target, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str target_id: The target id corresponding to the target you want to update (required)
        :param Target updated_target: The target to update. (required)
        :return: Target
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['target_id', 'updated_target']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method target_update_target" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'target_id' is set
        if self.api_client.client_side_validation and ('target_id' not in params or
                                                       params['target_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `target_id` when calling `target_update_target`")  # noqa: E501
        # verify the required parameter 'updated_target' is set
        if self.api_client.client_side_validation and ('updated_target' not in params or
                                                       params['updated_target'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `updated_target` when calling `target_update_target`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'target_id' in params:
            path_params['targetId'] = params['target_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'updated_target' in params:
            body_params = params['updated_target']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json-patch+json', 'application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/target/{targetId}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Target',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Trackside Software TeamDB API v2.0

    This API enables you to access TeamDB data  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@trackside.fr
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from teamdbapi.api_client import ApiClient


class TrackApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def track_create_track(self, new_track, **kwargs):  # noqa: E501
        """Create a new track  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.track_create_track(new_track, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param Track new_track: The track to create. (required)
        :return: Track
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.track_create_track_with_http_info(new_track, **kwargs)  # noqa: E501
        else:
            (data) = self.track_create_track_with_http_info(new_track, **kwargs)  # noqa: E501
            return data

    def track_create_track_with_http_info(self, new_track, **kwargs):  # noqa: E501
        """Create a new track  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.track_create_track_with_http_info(new_track, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param Track new_track: The track to create. (required)
        :return: Track
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['new_track']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method track_create_track" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'new_track' is set
        if self.api_client.client_side_validation and ('new_track' not in params or
                                                       params['new_track'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `new_track` when calling `track_create_track`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'new_track' in params:
            body_params = params['new_track']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json-patch+json', 'application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/track', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Track',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def track_delete_track(self, track_id, **kwargs):  # noqa: E501
        """Delete an existing track  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.track_delete_track(track_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str track_id: The unique track id for which you want to delete the track (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.track_delete_track_with_http_info(track_id, **kwargs)  # noqa: E501
        else:
            (data) = self.track_delete_track_with_http_info(track_id, **kwargs)  # noqa: E501
            return data

    def track_delete_track_with_http_info(self, track_id, **kwargs):  # noqa: E501
        """Delete an existing track  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.track_delete_track_with_http_info(track_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str track_id: The unique track id for which you want to delete the track (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['track_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method track_delete_track" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'track_id' is set
        if self.api_client.client_side_validation and ('track_id' not in params or
                                                       params['track_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `track_id` when calling `track_delete_track`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'track_id' in params:
            path_params['trackId'] = params['track_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/track/{trackId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def track_get_track(self, track_id, **kwargs):  # noqa: E501
        """Get an track via a unique id.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.track_get_track(track_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str track_id: The unique track id for which you want to get the track (required)
        :return: Track
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.track_get_track_with_http_info(track_id, **kwargs)  # noqa: E501
        else:
            (data) = self.track_get_track_with_http_info(track_id, **kwargs)  # noqa: E501
            return data

    def track_get_track_with_http_info(self, track_id, **kwargs):  # noqa: E501
        """Get an track via a unique id.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.track_get_track_with_http_info(track_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str track_id: The unique track id for which you want to get the track (required)
        :return: Track
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['track_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method track_get_track" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'track_id' is set
        if self.api_client.client_side_validation and ('track_id' not in params or
                                                       params['track_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `track_id` when calling `track_get_track`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'track_id' in params:
            path_params['trackId'] = params['track_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/track/{trackId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Track',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def track_get_tracks(self, **kwargs):  # noqa: E501
        """Get the list of all tracks  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.track_get_tracks(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: list[CoupleGuidText]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.track_get_tracks_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.track_get_tracks_with_http_info(**kwargs)  # noqa: E501
            return data

    def track_get_tracks_with_http_info(self, **kwargs):  # noqa: E501
        """Get the list of all tracks  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.track_get_tracks_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: list[CoupleGuidText]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method track_get_tracks" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/tracks', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[CoupleGuidText]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def track_update_track(self, track_id, updated_track, **kwargs):  # noqa: E501
        """Update an existing track  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.track_update_track(track_id, updated_track, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str track_id: The unique track id for which you want to update the track (required)
        :param Track updated_track: The track to update. (required)
        :return: Track
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.track_update_track_with_http_info(track_id, updated_track, **kwargs)  # noqa: E501
        else:
            (data) = self.track_update_track_with_http_info(track_id, updated_track, **kwargs)  # noqa: E501
            return data

    def track_update_track_with_http_info(self, track_id, updated_track, **kwargs):  # noqa: E501
        """Update an existing track  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.track_update_track_with_http_info(track_id, updated_track, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str track_id: The unique track id for which you want to update the track (required)
        :param Track updated_track: The track to update. (required)
        :return: Track
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['track_id', 'updated_track']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method track_update_track" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'track_id' is set
        if self.api_client.client_side_validation and ('track_id' not in params or
                                                       params['track_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `track_id` when calling `track_update_track`")  # noqa: E501
        # verify the required parameter 'updated_track' is set
        if self.api_client.client_side_validation and ('updated_track' not in params or
                                                       params['updated_track'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `updated_track` when calling `track_update_track`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'track_id' in params:
            path_params['trackId'] = params['track_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'updated_track' in params:
            body_params = params['updated_track']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json-patch+json', 'application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/track/{trackId}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Track',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Trackside Software TeamDB API v2.0

    This API enables you to access TeamDB data  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@trackside.fr
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from teamdbapi.configuration import Configuration


class StringWithFontStyle(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'text': 'str',
        'color_font': 'str',
        'back_color': 'str',
        'bold': 'str',
        'italic': 'str',
        'underline': 'str'
    }

    attribute_map = {
        'text': 'Text',
        'color_font': 'ColorFont',
        'back_color': 'BackColor',
        'bold': 'Bold',
        'italic': 'Italic',
        'underline': 'Underline'
    }

    def __init__(self, text=None, color_font=None, back_color=None, bold=None, italic=None, underline=None, _configuration=None):  # noqa: E501
        """StringWithFontStyle - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._text = None
        self._color_font = None
        self._back_color = None
        self._bold = None
        self._italic = None
        self._underline = None
        self.discriminator = None

        if text is not None:
            self.text = text
        if color_font is not None:
            self.color_font = color_font
        if back_color is not None:
            self.back_color = back_color
        if bold is not None:
            self.bold = bold
        if italic is not None:
            self.italic = italic
        if underline is not None:
            self.underline = underline

    @property
    def text(self):
        """Gets the text of this StringWithFontStyle.  # noqa: E501

        The text  # noqa: E501

        :return: The text of this StringWithFontStyle.  # noqa: E501
        :rtype: str
        """
        return self._text

    @text.setter
    def text(self, text):
        """Sets the text of this StringWithFontStyle.

        The text  # noqa: E501

        :param text: The text of this StringWithFontStyle.  # noqa: E501
        :type: str
        """

        self._text = text

    @property
    def color_font(self):
        """Gets the color_font of this StringWithFontStyle.  # noqa: E501

        The font color. You must enter a ARGB hex value : #FF12EE33  # noqa: E501

        :return: The color_font of this StringWithFontStyle.  # noqa: E501
        :rtype: str
        """
        return self._color_font

    @color_font.setter
    def color_font(self, color_font):
        """Sets the color_font of this StringWithFontStyle.

        The font color. You must enter a ARGB hex value : #FF12EE33  # noqa: E501

        :param color_font: The color_font of this StringWithFontStyle.  # noqa: E501
        :type: str
        """

        self._color_font = color_font

    @property
    def back_color(self):
        """Gets the back_color of this StringWithFontStyle.  # noqa: E501

        The background color. You must enter a ARGB hex value : #FF12EE33  # noqa: E501

        :return: The back_color of this StringWithFontStyle.  # noqa: E501
        :rtype: str
        """
        return self._back_color

    @back_color.setter
    def back_color(self, back_color):
        """Sets the back_color of this StringWithFontStyle.

        The background color. You must enter a ARGB hex value : #FF12EE33  # noqa: E501

        :param back_color: The back_color of this StringWithFontStyle.  # noqa: E501
        :type: str
        """

        self._back_color = back_color

    @property
    def bold(self):
        """Gets the bold of this StringWithFontStyle.  # noqa: E501

        Specify whether the font style is bold  # noqa: E501

        :return: The bold of this StringWithFontStyle.  # noqa: E501
        :rtype: str
        """
        return self._bold

    @bold.setter
    def bold(self, bold):
        """Sets the bold of this StringWithFontStyle.

        Specify whether the font style is bold  # noqa: E501

        :param bold: The bold of this StringWithFontStyle.  # noqa: E501
        :type: str
        """
        allowed_values = ["Regular", "Bold", "Italic", "Underline", "Strikeout"]  # noqa: E501
        if (self._configuration.client_side_validation and
                bold not in allowed_values):
            raise ValueError(
                "Invalid value for `bold` ({0}), must be one of {1}"  # noqa: E501
                .format(bold, allowed_values)
            )

        self._bold = bold

    @property
    def italic(self):
        """Gets the italic of this StringWithFontStyle.  # noqa: E501

        Specify whether the font style is italic  # noqa: E501

        :return: The italic of this StringWithFontStyle.  # noqa: E501
        :rtype: str
        """
        return self._italic

    @italic.setter
    def italic(self, italic):
        """Sets the italic of this StringWithFontStyle.

        Specify whether the font style is italic  # noqa: E501

        :param italic: The italic of this StringWithFontStyle.  # noqa: E501
        :type: str
        """
        allowed_values = ["Regular", "Bold", "Italic", "Underline", "Strikeout"]  # noqa: E501
        if (self._configuration.client_side_validation and
                italic not in allowed_values):
            raise ValueError(
                "Invalid value for `italic` ({0}), must be one of {1}"  # noqa: E501
                .format(italic, allowed_values)
            )

        self._italic = italic

    @property
    def underline(self):
        """Gets the underline of this StringWithFontStyle.  # noqa: E501

        Specify whether the font style is underline  # noqa: E501

        :return: The underline of this StringWithFontStyle.  # noqa: E501
        :rtype: str
        """
        return self._underline

    @underline.setter
    def underline(self, underline):
        """Sets the underline of this StringWithFontStyle.

        Specify whether the font style is underline  # noqa: E501

        :param underline: The underline of this StringWithFontStyle.  # noqa: E501
        :type: str
        """
        allowed_values = ["Regular", "Bold", "Italic", "Underline", "Strikeout"]  # noqa: E501
        if (self._configuration.client_side_validation and
                underline not in allowed_values):
            raise ValueError(
                "Invalid value for `underline` ({0}), must be one of {1}"  # noqa: E501
                .format(underline, allowed_values)
            )

        self._underline = underline

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(StringWithFontStyle, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StringWithFontStyle):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, StringWithFontStyle):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Trackside Software TeamDB API v2.0

    This API enables you to access TeamDB data  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@trackside.fr
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from teamdbapi.configuration import Configuration


class FixedField(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'display_name': 'str',
        'property_name': 'str',
        'entity_type': 'str',
        'value_type': 'str',
        'read_only': 'bool',
        'table_reference': 'str',
        'is_computable': 'bool'
    }

    attribute_map = {
        'id': 'Id',
        'display_name': 'DisplayName',
        'property_name': 'PropertyName',
        'entity_type': 'EntityType',
        'value_type': 'ValueType',
        'read_only': 'ReadOnly',
        'table_reference': 'TableReference',
        'is_computable': 'IsComputable'
    }

    def __init__(self, id=None, display_name=None, property_name=None, entity_type=None, value_type=None, read_only=None, table_reference=None, is_computable=None, _configuration=None):  # noqa: E501
        """FixedField - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._id = None
        self._display_name = None
        self._property_name = None
        self._entity_type = None
        self._value_type = None
        self._read_only = None
        self._table_reference = None
        self._is_computable = None
        self.discriminator = None

        self.id = id
        self.display_name = display_name
        self.property_name = property_name
        self.entity_type = entity_type
        self.value_type = value_type
        if read_only is not None:
            self.read_only = read_only
        if table_reference is not None:
            self.table_reference = table_reference
        if is_computable is not None:
            self.is_computable = is_computable

    @property
    def id(self):
        """Gets the id of this FixedField.  # noqa: E501

        The unique fixed field Id.  # noqa: E501

        :return: The id of this FixedField.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this FixedField.

        The unique fixed field Id.  # noqa: E501

        :param id: The id of this FixedField.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def display_name(self):
        """Gets the display_name of this FixedField.  # noqa: E501

        The fixed field display name.  # noqa: E501

        :return: The display_name of this FixedField.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this FixedField.

        The fixed field display name.  # noqa: E501

        :param display_name: The display_name of this FixedField.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and display_name is None:
            raise ValueError("Invalid value for `display_name`, must not be `None`")  # noqa: E501
        if (self._configuration.client_side_validation and
                display_name is not None and len(display_name) < 1):
            raise ValueError("Invalid value for `display_name`, length must be greater than or equal to `1`")  # noqa: E501

        self._display_name = display_name

    @property
    def property_name(self):
        """Gets the property_name of this FixedField.  # noqa: E501

        The name of the property associated with the fixed field.  # noqa: E501

        :return: The property_name of this FixedField.  # noqa: E501
        :rtype: str
        """
        return self._property_name

    @property_name.setter
    def property_name(self, property_name):
        """Sets the property_name of this FixedField.

        The name of the property associated with the fixed field.  # noqa: E501

        :param property_name: The property_name of this FixedField.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and property_name is None:
            raise ValueError("Invalid value for `property_name`, must not be `None`")  # noqa: E501
        if (self._configuration.client_side_validation and
                property_name is not None and len(property_name) < 1):
            raise ValueError("Invalid value for `property_name`, length must be greater than or equal to `1`")  # noqa: E501

        self._property_name = property_name

    @property
    def entity_type(self):
        """Gets the entity_type of this FixedField.  # noqa: E501

        The entity type which contains the fixed field.  # noqa: E501

        :return: The entity_type of this FixedField.  # noqa: E501
        :rtype: str
        """
        return self._entity_type

    @entity_type.setter
    def entity_type(self, entity_type):
        """Sets the entity_type of this FixedField.

        The entity type which contains the fixed field.  # noqa: E501

        :param entity_type: The entity_type of this FixedField.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and entity_type is None:
            raise ValueError("Invalid value for `entity_type`, must not be `None`")  # noqa: E501
        allowed_values = ["Event", "Session", "Run", "Lap", "Car"]  # noqa: E501
        if (self._configuration.client_side_validation and
                entity_type not in allowed_values):
            raise ValueError(
                "Invalid value for `entity_type` ({0}), must be one of {1}"  # noqa: E501
                .format(entity_type, allowed_values)
            )

        self._entity_type = entity_type

    @property
    def value_type(self):
        """Gets the value_type of this FixedField.  # noqa: E501

        The fixed field value type.  # noqa: E501

        :return: The value_type of this FixedField.  # noqa: E501
        :rtype: str
        """
        return self._value_type

    @value_type.setter
    def value_type(self, value_type):
        """Sets the value_type of this FixedField.

        The fixed field value type.  # noqa: E501

        :param value_type: The value_type of this FixedField.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and value_type is None:
            raise ValueError("Invalid value for `value_type`, must not be `None`")  # noqa: E501
        allowed_values = ["Double", "String", "Bool", "TimeSpan", "DateTime", "TeamDBList", "Int", "Rtf", "StringMultiline", "TeamDBGrid", "Image", "File", "RevisionSelector", "RevisionEditor", "HyperlinkTextBox", "HyperlinkIntTextBox", "LifingRunMountingDiff", "Files", "Text"]  # noqa: E501
        if (self._configuration.client_side_validation and
                value_type not in allowed_values):
            raise ValueError(
                "Invalid value for `value_type` ({0}), must be one of {1}"  # noqa: E501
                .format(value_type, allowed_values)
            )

        self._value_type = value_type

    @property
    def read_only(self):
        """Gets the read_only of this FixedField.  # noqa: E501

        Set to True for a read only fixed field.  # noqa: E501

        :return: The read_only of this FixedField.  # noqa: E501
        :rtype: bool
        """
        return self._read_only

    @read_only.setter
    def read_only(self, read_only):
        """Sets the read_only of this FixedField.

        Set to True for a read only fixed field.  # noqa: E501

        :param read_only: The read_only of this FixedField.  # noqa: E501
        :type: bool
        """

        self._read_only = read_only

    @property
    def table_reference(self):
        """Gets the table_reference of this FixedField.  # noqa: E501

        The table name if referenced for the data.  # noqa: E501

        :return: The table_reference of this FixedField.  # noqa: E501
        :rtype: str
        """
        return self._table_reference

    @table_reference.setter
    def table_reference(self, table_reference):
        """Sets the table_reference of this FixedField.

        The table name if referenced for the data.  # noqa: E501

        :param table_reference: The table_reference of this FixedField.  # noqa: E501
        :type: str
        """

        self._table_reference = table_reference

    @property
    def is_computable(self):
        """Gets the is_computable of this FixedField.  # noqa: E501

        Set to True if the fixed field can be used for a computed field.  # noqa: E501

        :return: The is_computable of this FixedField.  # noqa: E501
        :rtype: bool
        """
        return self._is_computable

    @is_computable.setter
    def is_computable(self, is_computable):
        """Sets the is_computable of this FixedField.

        Set to True if the fixed field can be used for a computed field.  # noqa: E501

        :param is_computable: The is_computable of this FixedField.  # noqa: E501
        :type: bool
        """

        self._is_computable = is_computable

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(FixedField, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FixedField):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, FixedField):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Trackside Software TeamDB API v2.0

    This API enables you to access TeamDB data  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@trackside.fr
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from teamdbapi.api_client import ApiClient


class NotesAuthorizationApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def notes_authorization_get_notes_authorizations(self, itembase_id, **kwargs):  # noqa: E501
        """Get the list of authorizations for a given Id corresponding to an Event or a Car  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.notes_authorization_get_notes_authorizations(itembase_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str itembase_id: Unique Id corresponding to an Event or a Car (required)
        :return: list[NotesAuthorization]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.notes_authorization_get_notes_authorizations_with_http_info(itembase_id, **kwargs)  # noqa: E501
        else:
            (data) = self.notes_authorization_get_notes_authorizations_with_http_info(itembase_id, **kwargs)  # noqa: E501
            return data

    def notes_authorization_get_notes_authorizations_with_http_info(self, itembase_id, **kwargs):  # noqa: E501
        """Get the list of authorizations for a given Id corresponding to an Event or a Car  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.notes_authorization_get_notes_authorizations_with_http_info(itembase_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str itembase_id: Unique Id corresponding to an Event or a Car (required)
        :return: list[NotesAuthorization]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['itembase_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method notes_authorization_get_notes_authorizations" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'itembase_id' is set
        if self.api_client.client_side_validation and ('itembase_id' not in params or
                                                       params['itembase_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `itembase_id` when calling `notes_authorization_get_notes_authorizations`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'itembase_id' in params:
            path_params['itembaseId'] = params['itembase_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/itembase/{itembaseId}/notesauthorizations', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[NotesAuthorization]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def notes_authorization_has_acces(self, itembase_id, user_or_group_id, **kwargs):  # noqa: E501
        """Returns true if the user or group has access to the event or car  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.notes_authorization_has_acces(itembase_id, user_or_group_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str itembase_id: Unique Id corresponding to an Event or a Car (required)
        :param str user_or_group_id: Unique Id corresponding to a User or a Group (required)
        :return: bool
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.notes_authorization_has_acces_with_http_info(itembase_id, user_or_group_id, **kwargs)  # noqa: E501
        else:
            (data) = self.notes_authorization_has_acces_with_http_info(itembase_id, user_or_group_id, **kwargs)  # noqa: E501
            return data

    def notes_authorization_has_acces_with_http_info(self, itembase_id, user_or_group_id, **kwargs):  # noqa: E501
        """Returns true if the user or group has access to the event or car  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.notes_authorization_has_acces_with_http_info(itembase_id, user_or_group_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str itembase_id: Unique Id corresponding to an Event or a Car (required)
        :param str user_or_group_id: Unique Id corresponding to a User or a Group (required)
        :return: bool
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['itembase_id', 'user_or_group_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method notes_authorization_has_acces" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'itembase_id' is set
        if self.api_client.client_side_validation and ('itembase_id' not in params or
                                                       params['itembase_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `itembase_id` when calling `notes_authorization_has_acces`")  # noqa: E501
        # verify the required parameter 'user_or_group_id' is set
        if self.api_client.client_side_validation and ('user_or_group_id' not in params or
                                                       params['user_or_group_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `user_or_group_id` when calling `notes_authorization_has_acces`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'itembase_id' in params:
            path_params['itembaseId'] = params['itembase_id']  # noqa: E501

        query_params = []
        if 'user_or_group_id' in params:
            query_params.append(('userOrGroupId', params['user_or_group_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/itembase/{itembaseId}/hasacces', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='bool',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def notes_authorization_set_notes_authorizations(self, authorization, **kwargs):  # noqa: E501
        """[Command] Set an authorization to a user or a group for an event or a car.  To give acces to a user or group you have to fill the ConcernedEntityId (user or group Id), ConcernedEntityIsGroup (true if group), ItembaseId (event or car id) and set HasAccess to true.  To remove the access to a user or group you have to fill the Id (the existing authorization unique id), ConcernedEntityId (user or group Id), ConcernedEntityIsGroup (true if group), ItembaseId (event or car id) and set HasAccess to false.  Notice : you have to load the event or car data before to set the authorization. Event or car data must be loaded locally first to any action.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.notes_authorization_set_notes_authorizations(authorization, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param NotesAuthorization authorization: The authorization to set (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.notes_authorization_set_notes_authorizations_with_http_info(authorization, **kwargs)  # noqa: E501
        else:
            (data) = self.notes_authorization_set_notes_authorizations_with_http_info(authorization, **kwargs)  # noqa: E501
            return data

    def notes_authorization_set_notes_authorizations_with_http_info(self, authorization, **kwargs):  # noqa: E501
        """[Command] Set an authorization to a user or a group for an event or a car.  To give acces to a user or group you have to fill the ConcernedEntityId (user or group Id), ConcernedEntityIsGroup (true if group), ItembaseId (event or car id) and set HasAccess to true.  To remove the access to a user or group you have to fill the Id (the existing authorization unique id), ConcernedEntityId (user or group Id), ConcernedEntityIsGroup (true if group), ItembaseId (event or car id) and set HasAccess to false.  Notice : you have to load the event or car data before to set the authorization. Event or car data must be loaded locally first to any action.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.notes_authorization_set_notes_authorizations_with_http_info(authorization, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param NotesAuthorization authorization: The authorization to set (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['authorization']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method notes_authorization_set_notes_authorizations" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'authorization' is set
        if self.api_client.client_side_validation and ('authorization' not in params or
                                                       params['authorization'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `authorization` when calling `notes_authorization_set_notes_authorizations`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'authorization' in params:
            body_params = params['authorization']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json-patch+json', 'application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/notesauthorizations', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Trackside Software TeamDB API v2.0

    This API enables you to access TeamDB data  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@trackside.fr
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from teamdbapi.configuration import Configuration


class Session(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'name': 'str',
        'number': 'int',
        'car_id': 'str',
        'track_layout_id': 'str',
        'session_date': 'datetime',
        'session_status': 'str',
        'last_update_date_utc': 'datetime',
        'last_update_user': 'str',
        'revision': 'int',
        'lap_count': 'int',
        'run_count': 'int',
        'distance': 'float',
        'distance_real': 'float',
        'default_assemblies': 'list[str]',
        'duration': 'float'
    }

    attribute_map = {
        'id': 'Id',
        'name': 'Name',
        'number': 'Number',
        'car_id': 'CarId',
        'track_layout_id': 'TrackLayoutId',
        'session_date': 'SessionDate',
        'session_status': 'SessionStatus',
        'last_update_date_utc': 'LastUpdateDateUtc',
        'last_update_user': 'LastUpdateUser',
        'revision': 'Revision',
        'lap_count': 'LapCount',
        'run_count': 'RunCount',
        'distance': 'Distance',
        'distance_real': 'DistanceReal',
        'default_assemblies': 'DefaultAssemblies',
        'duration': 'Duration'
    }

    def __init__(self, id=None, name=None, number=None, car_id=None, track_layout_id=None, session_date=None, session_status=None, last_update_date_utc=None, last_update_user=None, revision=None, lap_count=None, run_count=None, distance=None, distance_real=None, default_assemblies=None, duration=None, _configuration=None):  # noqa: E501
        """Session - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._id = None
        self._name = None
        self._number = None
        self._car_id = None
        self._track_layout_id = None
        self._session_date = None
        self._session_status = None
        self._last_update_date_utc = None
        self._last_update_user = None
        self._revision = None
        self._lap_count = None
        self._run_count = None
        self._distance = None
        self._distance_real = None
        self._default_assemblies = None
        self._duration = None
        self.discriminator = None

        self.id = id
        self.name = name
        self.number = number
        self.car_id = car_id
        self.track_layout_id = track_layout_id
        self.session_date = session_date
        if session_status is not None:
            self.session_status = session_status
        if last_update_date_utc is not None:
            self.last_update_date_utc = last_update_date_utc
        if last_update_user is not None:
            self.last_update_user = last_update_user
        if revision is not None:
            self.revision = revision
        if lap_count is not None:
            self.lap_count = lap_count
        if run_count is not None:
            self.run_count = run_count
        if distance is not None:
            self.distance = distance
        if distance_real is not None:
            self.distance_real = distance_real
        if default_assemblies is not None:
            self.default_assemblies = default_assemblies
        if duration is not None:
            self.duration = duration

    @property
    def id(self):
        """Gets the id of this Session.  # noqa: E501

        The unique session Id.  Set the Id to Guid.Empty (00000000-0000-0000-0000-000000000000) if you want to create a new Session.  # noqa: E501

        :return: The id of this Session.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Session.

        The unique session Id.  Set the Id to Guid.Empty (00000000-0000-0000-0000-000000000000) if you want to create a new Session.  # noqa: E501

        :param id: The id of this Session.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def name(self):
        """Gets the name of this Session.  # noqa: E501

        The session name.  # noqa: E501

        :return: The name of this Session.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Session.

        The session name.  # noqa: E501

        :param name: The name of this Session.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501
        if (self._configuration.client_side_validation and
                name is not None and len(name) < 1):
            raise ValueError("Invalid value for `name`, length must be greater than or equal to `1`")  # noqa: E501

        self._name = name

    @property
    def number(self):
        """Gets the number of this Session.  # noqa: E501

        The session number.  # noqa: E501

        :return: The number of this Session.  # noqa: E501
        :rtype: int
        """
        return self._number

    @number.setter
    def number(self, number):
        """Sets the number of this Session.

        The session number.  # noqa: E501

        :param number: The number of this Session.  # noqa: E501
        :type: int
        """
        if self._configuration.client_side_validation and number is None:
            raise ValueError("Invalid value for `number`, must not be `None`")  # noqa: E501

        self._number = number

    @property
    def car_id(self):
        """Gets the car_id of this Session.  # noqa: E501

        The car unique id to which the session is linked.  # noqa: E501

        :return: The car_id of this Session.  # noqa: E501
        :rtype: str
        """
        return self._car_id

    @car_id.setter
    def car_id(self, car_id):
        """Sets the car_id of this Session.

        The car unique id to which the session is linked.  # noqa: E501

        :param car_id: The car_id of this Session.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and car_id is None:
            raise ValueError("Invalid value for `car_id`, must not be `None`")  # noqa: E501

        self._car_id = car_id

    @property
    def track_layout_id(self):
        """Gets the track_layout_id of this Session.  # noqa: E501

        The track layout unique id.  # noqa: E501

        :return: The track_layout_id of this Session.  # noqa: E501
        :rtype: str
        """
        return self._track_layout_id

    @track_layout_id.setter
    def track_layout_id(self, track_layout_id):
        """Sets the track_layout_id of this Session.

        The track layout unique id.  # noqa: E501

        :param track_layout_id: The track_layout_id of this Session.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and track_layout_id is None:
            raise ValueError("Invalid value for `track_layout_id`, must not be `None`")  # noqa: E501

        self._track_layout_id = track_layout_id

    @property
    def session_date(self):
        """Gets the session_date of this Session.  # noqa: E501

        The session date.  The date must be an UTC date time. Here is an example : 2018-06-05T12:36:34.168Z  # noqa: E501

        :return: The session_date of this Session.  # noqa: E501
        :rtype: datetime
        """
        return self._session_date

    @session_date.setter
    def session_date(self, session_date):
        """Sets the session_date of this Session.

        The session date.  The date must be an UTC date time. Here is an example : 2018-06-05T12:36:34.168Z  # noqa: E501

        :param session_date: The session_date of this Session.  # noqa: E501
        :type: datetime
        """
        if self._configuration.client_side_validation and session_date is None:
            raise ValueError("Invalid value for `session_date`, must not be `None`")  # noqa: E501

        self._session_date = session_date

    @property
    def session_status(self):
        """Gets the session_status of this Session.  # noqa: E501

        The session status.  # noqa: E501

        :return: The session_status of this Session.  # noqa: E501
        :rtype: str
        """
        return self._session_status

    @session_status.setter
    def session_status(self, session_status):
        """Sets the session_status of this Session.

        The session status.  # noqa: E501

        :param session_status: The session_status of this Session.  # noqa: E501
        :type: str
        """
        allowed_values = ["Normal", "Assembly", "Disassembly"]  # noqa: E501
        if (self._configuration.client_side_validation and
                session_status not in allowed_values):
            raise ValueError(
                "Invalid value for `session_status` ({0}), must be one of {1}"  # noqa: E501
                .format(session_status, allowed_values)
            )

        self._session_status = session_status

    @property
    def last_update_date_utc(self):
        """Gets the last_update_date_utc of this Session.  # noqa: E501

        The last utc date time when the properties of this object have been updated.  This field will be automatically updated from the server side each time you update the object.  # noqa: E501

        :return: The last_update_date_utc of this Session.  # noqa: E501
        :rtype: datetime
        """
        return self._last_update_date_utc

    @last_update_date_utc.setter
    def last_update_date_utc(self, last_update_date_utc):
        """Sets the last_update_date_utc of this Session.

        The last utc date time when the properties of this object have been updated.  This field will be automatically updated from the server side each time you update the object.  # noqa: E501

        :param last_update_date_utc: The last_update_date_utc of this Session.  # noqa: E501
        :type: datetime
        """

        self._last_update_date_utc = last_update_date_utc

    @property
    def last_update_user(self):
        """Gets the last_update_user of this Session.  # noqa: E501

        The name of the last user having updated this object.  This field will be automatically updated from the server side each time you update the object.  # noqa: E501

        :return: The last_update_user of this Session.  # noqa: E501
        :rtype: str
        """
        return self._last_update_user

    @last_update_user.setter
    def last_update_user(self, last_update_user):
        """Sets the last_update_user of this Session.

        The name of the last user having updated this object.  This field will be automatically updated from the server side each time you update the object.  # noqa: E501

        :param last_update_user: The last_update_user of this Session.  # noqa: E501
        :type: str
        """

        self._last_update_user = last_update_user

    @property
    def revision(self):
        """Gets the revision of this Session.  # noqa: E501

        The revision number of the object.  # noqa: E501

        :return: The revision of this Session.  # noqa: E501
        :rtype: int
        """
        return self._revision

    @revision.setter
    def revision(self, revision):
        """Sets the revision of this Session.

        The revision number of the object.  # noqa: E501

        :param revision: The revision of this Session.  # noqa: E501
        :type: int
        """

        self._revision = revision

    @property
    def lap_count(self):
        """Gets the lap_count of this Session.  # noqa: E501

        Lap count in the session  # noqa: E501

        :return: The lap_count of this Session.  # noqa: E501
        :rtype: int
        """
        return self._lap_count

    @lap_count.setter
    def lap_count(self, lap_count):
        """Sets the lap_count of this Session.

        Lap count in the session  # noqa: E501

        :param lap_count: The lap_count of this Session.  # noqa: E501
        :type: int
        """

        self._lap_count = lap_count

    @property
    def run_count(self):
        """Gets the run_count of this Session.  # noqa: E501

        Run count in the session  # noqa: E501

        :return: The run_count of this Session.  # noqa: E501
        :rtype: int
        """
        return self._run_count

    @run_count.setter
    def run_count(self, run_count):
        """Sets the run_count of this Session.

        Run count in the session  # noqa: E501

        :param run_count: The run_count of this Session.  # noqa: E501
        :type: int
        """

        self._run_count = run_count

    @property
    def distance(self):
        """Gets the distance of this Session.  # noqa: E501

        Distance performed during the session  # noqa: E501

        :return: The distance of this Session.  # noqa: E501
        :rtype: float
        """
        return self._distance

    @distance.setter
    def distance(self, distance):
        """Sets the distance of this Session.

        Distance performed during the session  # noqa: E501

        :param distance: The distance of this Session.  # noqa: E501
        :type: float
        """

        self._distance = distance

    @property
    def distance_real(self):
        """Gets the distance_real of this Session.  # noqa: E501

        Distance real performed during the session  # noqa: E501

        :return: The distance_real of this Session.  # noqa: E501
        :rtype: float
        """
        return self._distance_real

    @distance_real.setter
    def distance_real(self, distance_real):
        """Sets the distance_real of this Session.

        Distance real performed during the session  # noqa: E501

        :param distance_real: The distance_real of this Session.  # noqa: E501
        :type: float
        """

        self._distance_real = distance_real

    @property
    def default_assemblies(self):
        """Gets the default_assemblies of this Session.  # noqa: E501

        List of the default Assemblies used to create the first session's run.  You have to specify one assemblies by target.  # noqa: E501

        :return: The default_assemblies of this Session.  # noqa: E501
        :rtype: list[str]
        """
        return self._default_assemblies

    @default_assemblies.setter
    def default_assemblies(self, default_assemblies):
        """Sets the default_assemblies of this Session.

        List of the default Assemblies used to create the first session's run.  You have to specify one assemblies by target.  # noqa: E501

        :param default_assemblies: The default_assemblies of this Session.  # noqa: E501
        :type: list[str]
        """

        self._default_assemblies = default_assemblies

    @property
    def duration(self):
        """Gets the duration of this Session.  # noqa: E501

        The session duration in secondes  # noqa: E501

        :return: The duration of this Session.  # noqa: E501
        :rtype: float
        """
        return self._duration

    @duration.setter
    def duration(self, duration):
        """Sets the duration of this Session.

        The session duration in secondes  # noqa: E501

        :param duration: The duration of this Session.  # noqa: E501
        :type: float
        """

        self._duration = duration

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Session, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Session):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Session):
            return True

        return self.to_dict() != other.to_dict()
